@@ -1,42 +1,55 @@
 extern crate webframework as wfw;
 extern crate failure;
+extern crate lazy_static;
+extern crate regex;
 
 use crate::wfw::prelude::*;
 
-#[meta_controller]
-fn handle404(req: Request) -> WebResponse {
+#[controller]
+fn handle404(req: &Request) -> WebResponse {
     Ok(Response::from_string(format!("Could not find path {}", req.uri().path()))
         .with_status(StatusCode::NOT_FOUND))
 }
 
 #[controller]
-fn root(_req: Request) -> WebResponse {
+fn root() -> WebResponse {
     Ok(Response::from_string("Hello World!"))
 }
 
 #[controller]
-fn about(_req: Request) -> WebResponse {
+fn about() -> WebResponse {
     Ok(Response::from_string("About Webframework"))
 }
 
 #[controller]
-fn create_task(req: Request) -> WebResponse {
-    Ok(Response::from_string("Hello World!"))
+fn create_task() -> WebResponse {
+    Ok(Response::from_string("You can create a task here"))
 }
 
 #[controller]
-fn tasks(_req: Request) -> WebResponse {
+fn new_task() -> WebResponse {
+    Ok(Response::from_string("You can find a new task here"))
+}
+
+#[controller]
+fn tasks() -> WebResponse {
     Ok(Response::from_string("List of tasks!"))
 }
 
 #[controller]
-fn tasks_json(_req: Request) -> WebResponse {
+fn tasks_json() -> WebResponse {
     Ok(Response::from_string("{msg: \"List of tasks\"}"))
 }
 
+#[controller(params = "test")]
+fn dynamic_path(test: String) -> WebResponse {
+    Ok(Response::from_string(format!("Dynamic segment was: {}", test)))
+}
+
 routing! {
     TaskRouter => {
         POST "/create" => create_task;
+        GET "/new" => new_task;
         GET "/" => {
             html => tasks;
             json => tasks_json;
@@ -48,6 +61,7 @@ routing! {
     RootRouter => {
         delegate "/tasks" => TaskRouter;
         GET "/about" => about;
+        GET "/:test" => dynamic_path;
         GET "/" => root;
         >> NotFound => handle404;
     }
