@@ -1,22 +1,36 @@
-use failure::{Context, Fail};
+use failure::{Context, Fail, Backtrace};
 use std::fmt::{self, Display};
 
+#[derive(Clone, Debug, Fail)]
+pub enum ServiceErrorKind {
+    #[fail(display = "An Error spawning a new service")]
+    ServiceCreation,
+    #[fail(display = "An Error during handling a request")]
+    RequestError,
+    #[fail(display = "Unhandled request for path: {}", _0)]
+    UnhandledError(String),
+    #[fail(display = "Internal Error")]
+    InternalError,
+}
+
 #[derive(Debug)]
 pub struct ServiceError {
     inner: Context<ServiceErrorKind>,
 }
 
-#[derive(Copy, Clone, Eq, PartialEq, Debug, Fail)]
-pub enum ServiceErrorKind {
-    #[fail(display = "An Error spawning a new service")]
-    ServiceCreation,
-    #[fail(display = "An Error during handling a request")]
-    RequestError,
+impl Fail for ServiceError {
+    fn cause(&self) -> Option<&Fail> {
+        self.inner.cause()
+    }
+
+    fn backtrace(&self) -> Option<&Backtrace> {
+        self.inner.backtrace()
+    }
 }
 
 impl ServiceError {
     pub fn kind(&self) -> ServiceErrorKind {
-        *self.inner.get_context()
+        self.inner.get_context().clone()
     }
 }
 
@@ -37,6 +51,3 @@ impl Display for ServiceError {
         Display::fmt(&self.inner, f)
     }
 }
-
-impl std::error::Error for ServiceError {}
-
