@@ -1,20 +1,18 @@
 extern crate webframework_derive;
-#[macro_use] extern crate failure;
+extern crate webframework_core;
+extern crate failure;
 extern crate hyper;
 extern crate slog;
 extern crate slog_term;
 extern crate slog_async;
+extern crate regex;
+#[macro_use] extern crate horrorshow;
 
 pub mod prelude;
-pub mod request;
-pub mod response;
-pub mod request_filters;
+pub mod request_filter;
 pub mod server;
-pub mod router;
 pub mod error;
+mod templates;
 
 pub use webframework_derive::controller;
-pub use webframework_derive::meta_controller;
 pub use webframework_derive::routing;
-
-pub type WebResult<T> = ::std::result::Result<T, failure::Error>;
